@@ -402,6 +402,85 @@ class SPJ_query(Query):
             title of these CS courses and the description of comments whose rating is greater than 3
             given by these students
             """
+            
+            
+
+class SPJ_query2(Query):
+    @property
+    def sql(self):
+        return """
+            SELECT movie.title, reviewer.name FROM movie, rating, reviewer WHERE reviewer.name = "Josh Cates" AND rating.stars > 4.5
+            """
+    @property
+    def simplified_graph(self):
+        if not SPJ_query2._graph:
+            # Relation
+            ## Initialize nodes
+            # Relation
+            movie = Relation("movie", "movie")
+            rating = Relation("rating", "rating")
+            reviewer = Relation("reviewer", "reviewer")
+
+            # Attribute
+            mov_title = Attribute("mov_title", "title")
+            rev_name1 = Attribute("rev_name1", "name")
+            rev_name2 = Attribute("rev_name2", "name")
+            rating_stars_2 = Attribute("rating_stars_2", "stars")
+            
+            # Values
+            v_rev_name = Value("Josh Cates", "Josh Cates")
+            v_stars = Value("4.5", "4.5")
+            
+            ## Construct graph
+            query_graph = Query_graph("MovieQuery3")
+            query_graph.connect_membership(movie, mov_title)
+            query_graph.connect_membership(reviewer, rev_name1)
+            # query_graph.connect_transformation(avg, max_speed)
+            
+            query_graph.connect_simplified_join(movie, rating)
+            query_graph.connect_simplified_join(rating, reviewer)
+
+            query_graph.connect_selection(reviewer, rev_name2)
+            query_graph.connect_predicate(rev_name2, v_rev_name)
+
+            query_graph.connect_selection(rating, rating_stars_2)
+            query_graph.connect_predicate(rating_stars_2, v_stars, OperatorType.GreaterThan)
+            SPJ_query2._graph = query_graph
+        return SPJ_query2._graph
+
+    @property
+    def specific_templates(self):
+        if not hasattr(self, "_specific_templates"):
+            self._specific_templates = [Template_S_to_I(self.graph), Template_C_to_Val(self.graph), Template_I_to_C(self.graph)]
+        return self._specific_templates
+
+    @property
+    def templates(self):
+        return self.specific_templates + self.generic_templates
+    
+    @property
+    def template_set(self):
+        raise NotImplementedError("Need to add gold for template set")
+        return None
+
+    @property
+    def nl(self):
+        return self.BST_nl
+
+    @property
+    def BST_nl(self) -> str:
+        return """
+            
+            """
+
+    @property
+    def MRP_nl(self) -> str:
+        return ""
+
+    @property
+    def TMT_nl(self) -> str:
+        return """
+            """
 
 
 class GroupBy_query(Query):
